"use strict";(self.rspackChunk_JUPYTERLAB_CORE_OUTPUT=self.rspackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5938],{71129(e,r,t){t.r(r),t.d(r,{INotebookTree:()=>T,NotebookTreeWidget:()=>s});var o=t(99728),a=t(56292);class s extends a.TabPanel{constructor(){super({tabPlacement:"top",tabsMovable:!0,renderer:o.TabBarSvg.defaultRenderer}),this.addClass("jp-TreePanel")}}let T=new(t(37150)).Token("@jupyter-notebook/tree:INotebookTree")}}]);