"use strict";(self.rspackChunk_JUPYTERLAB_CORE_OUTPUT=self.rspackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[8299],{51014(r,e,t){t.d(e,{diagram:()=>u});var s=t(6271);t(62904),t(30100),t(43733),t(25474),t(22231),t(2967),t(3656),t(68460),t(59677),t(2961),t(74725);var a=t(87724),u={parser:s.Zk,get db(){return new s.u4(2)},renderer:s.q7,styles:s.tM,init:(0,a.K2)(r=>{r.state||(r.state={}),r.state.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")}}}]);