"use strict";(self.rspackChunk_JUPYTERLAB_CORE_OUTPUT=self.rspackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[1320],{44987(e,r,s){s.d(r,{diff:()=>t});var n={"+":"inserted","-":"deleted","@":"meta"};let t={name:"diff",token:function(e){var r=e.string.search(/[\t ]+?$/);if(!e.sol()||0===r)return e.skipToEnd(),("error "+(n[e.string.charAt(0)]||"")).replace(/ $/,"");var s=n[e.peek()]||e.skipToEnd();return -1===r?e.skipToEnd():e.pos=r,s}}}}]);